Represents an HTTP-level error that occurred while communicating with the Deputy API.
Summary
Functions
Callback implementation for Exception.message/1.
Types
Functions
Callback implementation for Exception.message/1.
Represents an HTTP-level error that occurred while communicating with the Deputy API.
Callback implementation for Exception.message/1.
Callback implementation for Exception.message/1.