Represents a rate limit error from the Deputy API.
Summary
Functions
Callback implementation for Exception.message/1.
Types
Functions
Callback implementation for Exception.message/1.
Represents a rate limit error from the Deputy API.
Callback implementation for Exception.message/1.
Callback implementation for Exception.message/1.